==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/billing/v20180709/models/DescribeSavingPlanCoverageResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.billing.v20180709.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeSavingPlanCoverageResponse extends AbstractModel {

    /**
    * 节省计划覆盖率明细数据
    */
    @SerializedName("DetailSet")
    @Expose
    private SavingPlanCoverageDetail [] DetailSet;

    /**
    * 节省计划覆盖率聚合数据
    */
    @SerializedName("RateSet")
    @Expose
    private SavingPlanCoverageRate [] RateSet;

    /**
    * 查询命中的节省计划覆盖率明细数据总条数
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 节省计划覆盖率明细数据 
     * @return DetailSet 节省计划覆盖率明细数据
     */
    public SavingPlanCoverageDetail [] getDetailSet() {
        return this.DetailSet;
    }

    /**
     * Set 节省计划覆盖率明细数据
     * @param DetailSet 节省计划覆盖率明细数据
     */
    public void setDetailSet(SavingPlanCoverageDetail [] DetailSet) {
        this.DetailSet = DetailSet;
    }

    /**
     * Get 节省计划覆盖率聚合数据 
     * @return RateSet 节省计划覆盖率聚合数据
     */
    public SavingPlanCoverageRate [] getRateSet() {
        return this.RateSet;
    }

    /**
     * Set 节省计划覆盖率聚合数据
     * @param RateSet 节省计划覆盖率聚合数据
     */
    public void setRateSet(SavingPlanCoverageRate [] RateSet) {
        this.RateSet = RateSet;
    }

    /**
     * Get 查询命中的节省计划覆盖率明细数据总条数 
     * @return TotalCount 查询命中的节省计划覆盖率明细数据总条数
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 查询命中的节省计划覆盖率明细数据总条数
     * @param TotalCount 查询命中的节省计划覆盖率明细数据总条数
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeSavingPlanCoverageResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeSavingPlanCoverageResponse(DescribeSavingPlanCoverageResponse source) {
        if (source.DetailSet != null) {
            this.DetailSet = new SavingPlanCoverageDetail[source.DetailSet.length];
            for (int i = 0; i < source.DetailSet.length; i++) {
                this.DetailSet[i] = new SavingPlanCoverageDetail(source.DetailSet[i]);
            }
        }
        if (source.RateSet != null) {
            this.RateSet = new SavingPlanCoverageRate[source.RateSet.length];
            for (int i = 0; i < source.RateSet.length; i++) {
                this.RateSet[i] = new SavingPlanCoverageRate(source.RateSet[i]);
            }
        }
        if (source.TotalCount != null) {
            this.TotalCount = new Long(source.TotalCount);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "DetailSet.", this.DetailSet);
        this.setParamArrayObj(map, prefix + "RateSet.", this.RateSet);
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1130-sources.jar: com/tencentcloudapi/billing/v20180709/models/DescribeSavingPlanCoverageResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.billing.v20180709.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeSavingPlanCoverageResponse extends AbstractModel {

    /**
    * 节省计划覆盖率明细数据
    */
    @SerializedName("DetailSet")
    @Expose
    private SavingPlanCoverageDetail [] DetailSet;

    /**
    * 节省计划覆盖率聚合数据
    */
    @SerializedName("RateSet")
    @Expose
    private SavingPlanCoverageRate [] RateSet;

    /**
    * 查询命中的节省计划覆盖率明细数据总条数
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 节省计划覆盖率明细数据 
     * @return DetailSet 节省计划覆盖率明细数据
     */
    public SavingPlanCoverageDetail [] getDetailSet() {
        return this.DetailSet;
    }

    /**
     * Set 节省计划覆盖率明细数据
     * @param DetailSet 节省计划覆盖率明细数据
     */
    public void setDetailSet(SavingPlanCoverageDetail [] DetailSet) {
        this.DetailSet = DetailSet;
    }

    /**
     * Get 节省计划覆盖率聚合数据 
     * @return RateSet 节省计划覆盖率聚合数据
     */
    public SavingPlanCoverageRate [] getRateSet() {
        return this.RateSet;
    }

    /**
     * Set 节省计划覆盖率聚合数据
     * @param RateSet 节省计划覆盖率聚合数据
     */
    public void setRateSet(SavingPlanCoverageRate [] RateSet) {
        this.RateSet = RateSet;
    }

    /**
     * Get 查询命中的节省计划覆盖率明细数据总条数 
     * @return TotalCount 查询命中的节省计划覆盖率明细数据总条数
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 查询命中的节省计划覆盖率明细数据总条数
     * @param TotalCount 查询命中的节省计划覆盖率明细数据总条数
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeSavingPlanCoverageResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeSavingPlanCoverageResponse(DescribeSavingPlanCoverageResponse source) {
        if (source.DetailSet != null) {
            this.DetailSet = new SavingPlanCoverageDetail[source.DetailSet.length];
            for (int i = 0; i < source.DetailSet.length; i++) {
                this.DetailSet[i] = new SavingPlanCoverageDetail(source.DetailSet[i]);
            }
        }
        if (source.RateSet != null) {
            this.RateSet = new SavingPlanCoverageRate[source.RateSet.length];
            for (int i = 0; i < source.RateSet.length; i++) {
                this.RateSet[i] = new SavingPlanCoverageRate(source.RateSet[i]);
            }
        }
        if (source.TotalCount != null) {
            this.TotalCount = new Long(source.TotalCount);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "DetailSet.", this.DetailSet);
        this.setParamArrayObj(map, prefix + "RateSet.", this.RateSet);
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
